translate.convert.po2ini

Package translate :: Package convert :: Module po2ini |
[hide private]
[frames] | no frames]

# Module po2ini

source code

convert Gettext PO localization files to .ini files

Classes | [hide private]
| reini

Functions | [hide private]
convertini(inputfile, outputfile, templatefile, includefuzzy=False, dialect="default") | source code
convertisl(inputfile, outputfile, templatefile, includefuzzy=False, dialect="inno") | source code
main(argv=None) | source code

Imports: factory